@@ -1,6 +1,8 @@
-__version__ = "0.3.0"
+__version__ = "0.3.2"
 
 from .websocket_subscription import WebsocketSubscription
 from .api import RestApiSession
 from . import bots
 from . import messages
+from . import walls
+from . import notes
