@@ -1,7 +1,18 @@
 def create(session, bot_id, x=None, y=None, color="gray", wall_text=None):
+    wall = {"color": color}
+    if x is not None:
+        wall['x'] = x
+    if y is not None:
+        wall['y'] = y
+    if wall_text is not None:
+        wall['wall_text'] = wall_text
+
     return session.post(
         "walls",
-        {"bot_id": bot_id, "x": x, "y": y, "color": color, "wall_text": wall_text},
+        {
+            "bot_id": bot_id,
+            "wall": wall,
+        },
     )
 
 
